#
# spec file for package blosc
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           blosc
Version:        1.6.1
Release:        5.21
%define major   1
%define libname lib%{name}%{major}
Summary:        A blocking, shuffling and lossless compression library
License:        MIT and BSD-3-Clause and BSD-2-Clause
Group:          System/Libraries
Url:            http://www.blosc.org/
# NOTE: you MUST rename the source to "v%{version}.tar.gz" or the source validator won't work
# github is weird because it renames files when you try to download them
Source:         https://github.com/Blosc/c-blosc/archive/v%{version}.tar.gz 
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  snappy-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Patch1:         0001-Fix-cmake-system-check.patch
Patch2:         0002-Fix-compilation-on-unknown-archs.patch

%description
Blosc is a high performance compressor optimized for binary data.
It has been designed to transmit data to the processor cache faster 
than the traditional, non-compressed, direct memory fetch approach via
a memcpy() OS call. Blosc is the first compressor (that I'm aware of) 
that is meant not only to reduce the size of large datasets on-disk or
in-memory, but also to accelerate memory-bound computations.

It uses the blocking technique to reduce activity on the memory bus as
much as possible. In short, this technique works by dividing datasets 
in blocks that are small enough to fit in caches  of modern processors
and perform compression / decompression there. It also leverages, if
available, SIMD instructions (SSE2) and  ulti-threading capabilities 
of CPUs, in order to accelerate the  compression / decompression 
process to a maximum.

Blosc is actually a metacompressor, that meaning that it can use a 
range of compression libraries for performing the actual 
compression/decompression. Right now, it comes with integrated support 
for BloscLZ (the original one), LZ4, LZ4HC, Snappy and Zlib. Blosc
comes with full sources for all compressors, so in case it does not 
find the libraries installed in your system, it will compile from 
the included sources and they will be integrated into the Blosc 
library anyway. That means that you can trust in having all supported 
compressors integrated in Blosc in all supported platforms.

%package -n %{libname}
Summary:        A blocking, shuffling and lossless compression library
Group:          System/Libraries

%description -n %{libname}
Blosc is a high performance compressor optimized for binary data.
It has been designed to transmit data to the processor cache faster 
than the traditional, non-compressed, direct memory fetch approach via
a memcpy() OS call. Blosc is the first compressor (that I'm aware of) 
that is meant not only to reduce the size of large datasets on-disk or
in-memory, but also to accelerate memory-bound computations.

It uses the blocking technique to reduce activity on the memory bus as
much as possible. In short, this technique works by dividing datasets 
in blocks that are small enough to fit in caches  of modern processors
and perform compression / decompression there. It also leverages, if
available, SIMD instructions (SSE2) and  ulti-threading capabilities 
of CPUs, in order to accelerate the  compression / decompression 
process to a maximum.

Blosc is actually a metacompressor, that meaning that it can use a 
range of compression libraries for performing the actual 
compression/decompression. Right now, it comes with integrated support 
for BloscLZ (the original one), LZ4, LZ4HC, Snappy and Zlib. Blosc
comes with full sources for all compressors, so in case it does not 
find the libraries installed in your system, it will compile from 
the included sources and they will be integrated into the Blosc 
library anyway. That means that you can trust in having all supported 
compressors integrated in Blosc in all supported platforms.

%package devel
Summary:        Development libraries for %{libname}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package provides development libraries and headers 
for %{libname}

%prep
%setup -q -n c-blosc-%{version}
%patch1	-p1
%patch2	-p1

%build
mkdir -p build
pushd build
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} \
%if "%{_lib}" == "lib64"
      -DLIB_SUFFIX=64 \
%endif
      -DCMAKE_C_FLAGS="%{optflags}" \
      -DCMAKE_CXX_FLAGS="%{optflags}" \
	  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
      ..
make %{?_smp_mflags}
popd

%install
pushd build
%makeinstall
rm -rf %{buildroot}%{_libdir}/libblosc.a

%check
pushd build
make test
popd

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root,-)
%doc ANNOUNCE.rst README.rst README_HEADER.rst README_THREADED.rst LICENSES/*.txt RELEASE_NOTES.rst
%{_libdir}/libblosc.so.%{major}
%{_libdir}/libblosc.so.%{version}

%files devel
%defattr(-,root,root,-)
%{_includedir}/blosc.h
%{_libdir}/libblosc.so

%changelog
* Fri Aug  7 2015 normand@linux.vnet.ibm.com
- Add two patches dragged from fedora to support non-intel archi
  0001-Fix-cmake-system-check.patch
  0002-Fix-compilation-on-unknown-archs.patch
* Tue May 19 2015 toddrme2178@gmail.com
- Update to version 1.6.1:
  * Fixed a subtle, but long-standing bug in the blosclz codec that
    could potentially overwrite an area beyond the output buffer.
  * Support for runtime detection of AVX2 and SSE2 SIMD
    instructions, allowing running AVX2 capable c-blosc libraries
    to run on machines with no AVX2 available (will use SSE2
    instead).
  * A new blocksize computation allows for better compression
    ratios for larger typesizes (> 8 bytes), without not penalizing
    the speed too much (at least on modern CPUs).
- changes from version 1.6.0:
  * Support for AVX2 is here!  The benchmarks with a 4-core Intel
    Haswell machine tell that both compression and decompression are
    accelerated around a 10%%, reaching peaks of 9.6 GB/s during
    compression and 26 GB/s during decompression (memcpy() speed for
    this machine is 7.5 GB/s for writes and 11.7 GB/s for reads).
    Many thanks to @littlezhou for this nice work.
  * Support for HPET (high precision timers) for the `bench` program.
    This is particularly important for microbenchmarks like bench is
    doing; since they take so little time to run, the granularity of a
    less-accurate timer may account for a significant portion of the
    runtime of the benchmark itself, skewing the results.  Thanks to
    Jack Pappas.
- changes from version 1.5.4:
  * Updated to LZ4 1.6.0 (r128).
  * Fix resource leak in t_blosc.  Jack Pappas.
  * Better checks during testing.  Jack Pappas.
  * Dynamically loadable HDF5 filter plugin. Kiyo Masui.
- changes from version 1.5.3:
  * Use llabs function (where available) instead of abs to avoid
    truncating the result.  Jack Pappas.
  * Use C11 aligned_alloc when it's available.  Jack Pappas.
  * Use the built-in stdint.h with MSVC when available.  Jack Pappas.
  * Only define the __SSE2__ symbol when compiling with MS Visual C++
    and targeting x64 or x86 with the correct /arch flag set. This
    avoids re-defining the symbol which makes other compilers issue
    warnings.  Jack Pappas.
  * Reinitializing Blosc during a call to set_nthreads() so as to fix
    problems with contexts.  Francesc Alted.
- changes from version 1.5.2:
  * Using blosc_compress_ctx() / blosc_decompress_ctx() inside the
    HDF5 compressor for allowing operation in multiprocess scenarios.
    See: https://github.com/PyTables/PyTables/issues/412
    The drawback of this quick fix is that the Blosc filter will be only
    able to use a single thread until another solution can be devised.
- changes from version 1.5.1:
  * Updated to LZ4 1.5.0.  Closes #74.
  * Added the 'const' qualifier to non SSE2 shuffle functions. Closes
    [#75].
  * Explicitly call blosc_init() in HDF5 blosc_filter.c, fixing a
    segfault.
  * Quite a few improvements in cmake files for HDF5 support.  Thanks
    to Dana Robinson (The HDF Group).
  * Variable 'class' caused problems compiling the HDF5 filter with
    g++.  Thanks to Laurent Chapon.
  * Small improvements on docstrings of c-blosc main functions.
- changes from version  1.5.0:
  * Added new calls for allowing Blosc to be used *simultaneously*
    (i.e. lock free) from multi-threaded environments.  The new
    functions are:
  - blosc_compress_ctx(...)
  - blosc_decompress_ctx(...)
    See the new docstrings in blosc.h for how to use them.  The previous
    API should be completely unaffected.  Thanks to Christopher Speller.
  * Optimized copies during BloscLZ decompression.  This can make
    BloscLZ to decompress up to 1.5x faster in some situations.
  * LZ4 and LZ4HC compressors updated to version 1.3.1.
  * Added an examples directory on how to link apps with Blosc.
  * stdlib.h moved from blosc.c to blosc.h as suggested by Rob Lathm.
  * Fix a warning for {snappy,lz4}-free compilation.  Thanks to Andrew
    Schaaf.
  * Several improvements for CMakeLists.txt (cmake).
  * Fixing C99 compatibility warnings.  Thanks to Christopher Speller.
- specfile:
  * update copyright year
* Tue Jul 22 2014 toddrme2178@gmail.com
- Cleanup .so files
* Tue Jul 22 2014 toddrme2178@gmail.com
- Use source url so source validation can run.
- Change group
- Cleanup post and postun
* Thu Jul 17 2014 toddrme2178@gmail.com
- Update to 1.4.1
  * Fixed a bug in blosc_getitem() introduced in 1.4.0.  Added a test for
    blosc_getitem() as well.
- Update to 1.4.0
  * Support for non-Intel and non-SSE2 architectures has been added.  In
    particular, the Raspberry Pi platform (ARM) has been tested and all
    tests pass here.
  * Architectures requiring strict access alignment are supported as well.
    Due to this, arquitectures with a high penalty in accessing unaligned
    data (e.g. Raspberry Pi, ARMv6) can compress up to 2.5x faster.
  * LZ4 has been updated to r119 (1.2.0) so as to fix a possible security
    breach.
- Update to 1.3.6
  * Updated to LZ4 r118 due to a (highly unlikely) security hole.  For
    details see:
* Thu May  8 2014 toddrme2178@gmail.com
- Initial version
